@@ -29,14 +29,14 @@ pub fn fragment_type(len: usize) -> usize {
 
 /// Storage of variable size values.
 pub struct ByteStorage {
-    pub file: Rc<SortedFile>,
-    pub id_gen: Cell<u64>,
+    pub(crate) file: Rc<SortedFile>,
+    id_gen: Cell<u64>,
     /// Bytes per fragment. One of 28, 60, 92, 124.
-    pub bpf: usize,
+    bpf: usize,
 }
 
 impl ByteStorage {
-    pub fn new(root_page: u64, ft: usize) -> Self {
+    pub(crate) fn new(root_page: u64, ft: usize) -> Self {
         // println!("ByteStorage::new root={} ft={}", root_page, ft );
         let bpf = 32 * ft + MINF;
         let file = Rc::new(SortedFile::new(9 + bpf, 8, root_page));
@@ -47,7 +47,7 @@ impl ByteStorage {
         }
     }
 
-    pub fn get_id(&self, db: &DB) -> u64 {
+    pub(crate) fn get_id(&self, db: &DB) -> u64 {
         let mut result = self.id_gen.get();
         if result == u64::MAX {
             result = 0;
@@ -62,11 +62,11 @@ impl ByteStorage {
         result
     }
 
-    pub fn save(&self, db: &DB, op: SaveOp) {
+    pub(crate) fn save(&self, db: &DB, op: SaveOp) {
         self.file.save(db, op);
     }
 
-    pub fn encode(&self, db: &DB, bytes: &[u8]) -> u64 {
+    pub(crate) fn encode(&self, db: &DB, bytes: &[u8]) -> u64 {
         let result = self.get_id(db);
         let mut r = Fragment::new(0, self.bpf);
         let n = bytes.len();
@@ -94,7 +94,7 @@ impl ByteStorage {
         result
     }
 
-    pub fn decode(&self, db: &DB, mut id: u64, inline: usize) -> Vec<u8> {
+    pub(crate) fn decode(&self, db: &DB, mut id: u64, inline: usize) -> Vec<u8> {
         let mut result = vec![0_u8; inline]; // inline bytes will be filled in from inline data.
         let start = Fragment::new(id, self.bpf);
         for (pp, off) in self.file.asc(db, Box::new(start)) {
@@ -112,7 +112,7 @@ impl ByteStorage {
         result
     }
 
-    pub fn delcode(&self, db: &DB, id: u64) {
+    pub(crate) fn delcode(&self, db: &DB, id: u64) {
         let start = Fragment::new(id, self.bpf);
         let mut n = 0;
         for (pp, off) in self.file.asc(db, Box::new(start)) {
@@ -133,7 +133,7 @@ impl ByteStorage {
     }
 
     #[cfg(feature = "pack")]
-    pub fn repack_file(&self, db: &DB) -> i64 {
+    pub(crate) fn repack_file(&self, db: &DB) -> i64 {
         let r = Fragment::new(0, self.bpf);
         self.file.repack(db, &r)
     }
