@@ -30,10 +30,10 @@ pub struct CompactFile {
     pub stg: Box<dyn Storage>,
 
     /// Size of starter page
-    pub sp_size: usize,
+    pub(crate) sp_size: usize,
 
     /// Size of extension page
-    pub ep_size: usize,
+    pub(crate) ep_size: usize,
 
     /// Number of extension pages reserved for starter pages.      
     ep_resvd: u64,
@@ -192,12 +192,11 @@ impl CompactFile {
         self.stg.write_vec(foff, info);
     }
 
-    /// Get logical page contents. Returns the page size.
+    /// Get logical page contents.
     pub fn get_page(&self, lpnum: u64) -> Data {
         if !self.lp_valid(lpnum) {
             return nd();
         }
-
         let mut starter = vec![0_u8; self.sp_size];
         let foff = Self::HSIZE + (self.sp_size as u64) * lpnum;
         self.stg.read(foff, &mut starter);
@@ -401,7 +400,7 @@ impl CompactFile {
     }
 
     /// Calculate the number of extension pages needed to store a page of given size.
-    pub fn ext_pages(sp_size: usize, ep_size: usize, size: usize) -> usize {
+    fn ext_pages(sp_size: usize, ep_size: usize, size: usize) -> usize {
         let mut n = 0;
         if size > (sp_size - 2) {
             n = ((size - (sp_size - 2)) + (ep_size - 16 - 1)) / (ep_size - 16);
