@@ -429,7 +429,7 @@ pub fn c_select(b: &mut Block, mut x: SelectExpression) -> CSelectExpression {
 /// Compile WHERE clause, using table index if possible.
 pub fn c_where(
     b: &Block,
-    table: Option<TablePtr>,
+    table: Option<Rc<Table>>,
     wher: &mut Option<Expr>,
 ) -> (Option<CExpPtr<bool>>, Option<CTableExpression>) {
     if let Some(we) = wher {
@@ -468,7 +468,7 @@ pub fn c_te(b: &Block, te: &mut TableExpression) -> CTableExpression {
     }
 }
 /// Look for named table in database.
-pub fn c_table(b: &Block, name: &ObjRef) -> TablePtr {
+pub fn c_table(b: &Block, name: &ObjRef) -> Rc<Table> {
     if let Some(t) = b.db.get_table(name) {
         t
     } else {
