@@ -1,13 +1,18 @@
 use crate::*;
 use Instruction::*;
 
-/// Evaluation environment - stack of Values, references to DB and Query.
+/// Evaluation environment - stack of Values, references to DB and Transaction.
 pub struct EvalEnv<'r> {
+    /// Stack of values, holds function parameters and local variables.
     pub stack: Vec<Value>,
-    pub bp: usize, // "Base Pointer" - used to access local variables.
+    /// "Base Pointer" - stack index of current parameters and local variables.
+    pub bp: usize,
+    /// Pointer to Database.
     pub db: DB,
+    /// Pointer to Transaction.
     pub tr: &'r mut dyn Transaction,
-    pub call_depth: usize,
+    /// Function call depth, prevents stack overflow.
+    call_depth: usize,
 }
 
 impl<'r> EvalEnv<'r> {
@@ -266,7 +271,7 @@ impl<'r> EvalEnv<'r> {
     }
 
     /// Execute INSERT operation.
-    fn insert(&mut self, t: TablePtr, cols: &[usize], src: &CTableExpression) {
+    fn insert(&mut self, t: Rc<Table>, cols: &[usize], src: &CTableExpression) {
         if let CTableExpression::Values(x) = src {
             self.insert_values(t, cols, x);
         } else {
@@ -423,7 +428,7 @@ impl<'r> EvalEnv<'r> {
     }
 
     /// Insert evaluated values into a table.
-    fn insert_values(&mut self, table: TablePtr, ci: &[usize], vals: &[Vec<CExpPtr<Value>>]) {
+    fn insert_values(&mut self, table: Rc<Table>, ci: &[usize], vals: &[Vec<CExpPtr<Value>>]) {
         let mut row = Row::new(table.info.clone());
         for r in vals {
             row.id = 0;
@@ -489,7 +494,7 @@ impl<'r> EvalEnv<'r> {
 
     fn drop_table(&mut self, name: &ObjRef) {
         if let Some(t) = sys::get_table(&self.db, name) {
-            let sql = format!("EXEC sys.DropTable({})", t.id);
+            let sql = format!("EXEC sys.DropTable){})", t.id);
             self.db.run(&sql, self.tr);
             self.db.tables.borrow_mut().remove(name);
             self.db.function_reset.set(true);
@@ -535,16 +540,17 @@ impl<'r> EvalEnv<'r> {
                     _ => {}
                 }
                 let sql = match act {
-                    AlterCol::Add(name, typ) => {
-                        format!("EXEC sys.AddColumn({},'{}',{})", t.id, name, typ)
-                    }
-                    AlterCol::Modify(name, typ) => {
-                        format!("EXEC sys.ModifyColumn({},'{}',{})", t.id, name, typ)
-                    }
-                    AlterCol::Drop(name) => {
-                        format!("EXEC sys.DropColumn({},'{}')", t.id, name)
-                    }
+                    AlterCol::Add(name, typ) => format!(
+                        "INSERT INTO sys.Column( Table, Name, Type ) VALUES ({}, '{}', {})",
+                        t.id, name, typ
+                    ),
+                    AlterCol::Modify(name, typ) => format!(
+                        "UPDATE sys.Column SET Type = {} WHERE Table = {} AND Name = '{}'",
+                        typ, t.id, name
+                    ),
+                    AlterCol::Drop(name) => format!("EXEC sys.DropColumn({},'{}')", t.id, name),
                 };
+                println!("sql={}", sql);
                 db.run(&sql, self.tr);
             }
 
