@@ -3,7 +3,7 @@ use Instruction::{DataOp, ForNext, ForSortNext, Jump, JumpIfFalse};
 
 /// Holds function name, line, column and message.
 #[derive(Clone)]
-pub struct SqlError {
+pub(crate) struct SqlError {
     pub rname: String,
     pub line: usize,
     pub column: usize,
@@ -12,13 +12,17 @@ pub struct SqlError {
 /// Table Expression ( not yet type-checked or compiled against database ).
 pub enum TableExpression {
     // Select( SelectExpression ),
+    ///
     Base(ObjRef),
+    ///
     Values(Vec<Vec<Expr>>),
 }
 /// Assign or Append.
 #[derive(Clone, Copy)]
 pub enum AssignOp {
+    ///
     Assign,
+    ///
     Append,
 }
 /// Vector of local variable numbers and AssignOp( assign or append ).
@@ -26,11 +30,17 @@ pub type Assigns = Vec<(usize, AssignOp)>;
 
 /// Select Expression ( not yet compiled ).
 pub struct SelectExpression {
+    ///
     pub colnames: Vec<String>,
+    ///
     pub assigns: Assigns,
+    ///
     pub exps: Vec<Expr>,
+    ///
     pub from: Option<Box<TableExpression>>,
+    ///
     pub wher: Option<Expr>,
+    ///
     pub orderby: Vec<(Expr, bool)>,
 }
 
@@ -38,37 +48,66 @@ pub struct SelectExpression {
 #[derive(Debug, PartialEq, PartialOrd, Clone, Copy)]
 pub enum Token {
     /* Note: order is significant */
+    ///
     Less,
+    ///
     LessEqual,
+    ///
     GreaterEqual,
+    ///
     Greater,
+    ///
     Equal,
+    ///
     NotEqual,
+    ///
     In,
+    ///
     Plus,
+    ///
     Minus,
+    ///
     Times,
+    ///
     Divide,
+    ///
     Percent,
+    ///
     VBar,
+    ///
     And,
+    ///
     Or,
+    ///
     VBarEqual,
+    ///
     Id,
+    ///
     Number,
+    ///
     Hex,
+    ///
     String,
+    ///
     LBra,
+    ///
     RBra,
+    ///
     Comma,
+    ///
     Colon,
+    ///
     Dot,
+    ///
     Exclamation,
+    ///
     Unknown,
+    ///
     EndOfFile,
 }
 
 impl Token {
+    ///
     pub fn precedence(self) -> i8 {
         const PA: [i8; 15] = [10, 10, 10, 10, 10, 10, 10, 20, 20, 30, 30, 30, 15, 8, 5];
         PA[self as usize]
@@ -77,14 +116,20 @@ impl Token {
 
 /// Scalar Expression (uncompiled).
 pub struct Expr {
+    ///
     pub exp: ExprIs,
+    ///
     pub data_type: DataType,
+    ///
     pub is_constant: bool, // Doesn't depend on FROM clause
+    ///
     pub checked: bool,
+    ///
     pub col: usize,
 }
 
 impl Expr {
+    ///
     pub fn new(exp: ExprIs) -> Self {
         Expr {
             exp,
@@ -98,27 +143,41 @@ impl Expr {
 
 /// Scalar Expression variants.
 pub enum ExprIs {
+    ///
     Const(Value),
+    ///
     Local(usize),
+    ///
     ColName(String),
+    ///
     Binary(Token, Box<Expr>, Box<Expr>),
+    ///
     Not(Box<Expr>),
+    ///
     Minus(Box<Expr>),
+    ///
     Case(Vec<(Expr, Expr)>, Box<Expr>),
+    ///
     FuncCall(ObjRef, Vec<Expr>),
+    ///
     BuiltinCall(String, Vec<Expr>),
+    ///
     ScalarSelect(Box<SelectExpression>),
+    ///
     List(Vec<Expr>),
 }
 
 /// Object reference ( Schema.Name ).
 #[derive(PartialEq, PartialOrd, Eq, Hash, Clone)]
 pub struct ObjRef {
+    ///
     pub schema: String,
+    ///
     pub name: String,
 }
 
 impl ObjRef {
+    /// Construct from string references.
     pub fn new(s: &str, n: &str) -> Self {
         Self {
             schema: s.to_string(),
@@ -134,30 +193,36 @@ impl ObjRef {
 /// Binary=1, String=2, Int=3, Float=4, Bool=5.
 #[derive(Debug, PartialEq, PartialOrd, Clone, Copy)]
 pub enum DataKind {
+    ///
     None = 0,
+    ///
     Binary = 1,
+    ///
     String = 2,
+    ///
     Int = 3,
+    ///
     Float = 4,
+    ///
     Bool = 5,
 }
 
-/// Low 3 (=[KBITS]) bits are DataKind, rest is size in bytes.
+/// Low 3 (KBITS) bits are DataKind, rest is size in bytes.
 pub type DataType = usize;
 
-pub const KBITS: usize = 3;
-pub const NONE: DataType = DataKind::None as usize;
-pub const BINARY: DataType = DataKind::Binary as usize + (16 << KBITS);
-pub const STRING: DataType = DataKind::String as usize + (16 << KBITS);
-pub const NAMESTR: DataType = DataKind::String as usize + (32 << KBITS);
-pub const BIGSTR: DataType = DataKind::String as usize + (250 << KBITS);
-pub const INT: DataType = DataKind::Int as usize + (8 << KBITS);
+pub(crate) const KBITS: usize = 3;
+pub(crate) const NONE: DataType = DataKind::None as usize;
+pub(crate) const BINARY: DataType = DataKind::Binary as usize + (16 << KBITS);
+pub(crate) const STRING: DataType = DataKind::String as usize + (16 << KBITS);
+pub(crate) const NAMESTR: DataType = DataKind::String as usize + (32 << KBITS);
+pub(crate) const BIGSTR: DataType = DataKind::String as usize + (250 << KBITS);
+pub(crate) const INT: DataType = DataKind::Int as usize + (8 << KBITS);
 //pub const INT4: DataType = DataKind::Int as usize + (4 << KBITS);
 //pub const INT2: DataType = DataKind::Int as usize + (2 << KBITS);
 //pub const INT1: DataType = DataKind::Int as usize + (1 << KBITS);
-pub const FLOAT: DataType = DataKind::Float as usize + (4 << KBITS);
-pub const DOUBLE: DataType = DataKind::Float as usize + (8 << KBITS);
-pub const BOOL: DataType = DataKind::Bool as usize + (1 << KBITS);
+pub(crate) const FLOAT: DataType = DataKind::Float as usize + (4 << KBITS);
+pub(crate) const DOUBLE: DataType = DataKind::Float as usize + (8 << KBITS);
+pub(crate) const BOOL: DataType = DataKind::Bool as usize + (1 << KBITS);
 
 /// Compute the DataKind of a DataType.
 pub fn data_kind(x: DataType) -> DataKind {
@@ -180,15 +245,21 @@ pub fn data_size(x: DataType) -> usize {
 
 /// Compilation block ( body of function or batch section ).
 pub struct Block<'a> {
+    ///
     pub param_count: usize,
+    ///
     pub return_type: DataType,
+    ///
     pub local_typ: Vec<DataType>,
+    ///
     pub ilist: Vec<Instruction>,
+    ///
     pub break_id: usize,
     /// Database.
     pub db: DB,
     /// Current table in scope by FROM clause( or UPDATE statment ).
     pub from: Option<CTableExpression>,
+    ///
     pub parse_only: bool,
     jumps: Vec<usize>,
     labels: HashMap<&'a [u8], usize>,
