@@ -1,3 +1,4 @@
+#![warn(missing_docs)]
 //! This crate (rustdb) implements a high-performance database written entirely in [Rust](https://www.rust-lang.org/).
 //!
 //! The SQL-like language is relatively minimal, and does not (currently) include features such as joins or views.
@@ -57,7 +58,7 @@
 //!
 //!# Features
 //!
-//! This crate supports two cargo features.
+//! This crate supports the following cargo features:
 //! - `builtin` : Allows extra SQL builtin functions to be defined.
 //! - `max` : Exposes maximal interface, including all internal modules (default).
 //! - `verify` : Allows database structure to be verified using builtin function VERIFYDB.
@@ -82,9 +83,13 @@
 //!
 //! [AtomicFile] ensures that database updates are all or nothing.
 //!
-//!# ToDo List
+//! The hierarchy overall: Table -> SortedFile -> PagedData -> CompactFile -> AtomicFile -> Storage.
 //!
-//! Unify GenTransaction and WebTransaction. File upload doesn't work with WebTransaction currently.
+//!# ToDo Lists
+//!
+//! Consider compiling R-SQL functions to Rust, effectively "automatic builtin" functions.
+//!
+//! Unify GenTransaction and WebTransaction. File upload only partially works with WebTransaction currently.
 //!
 //! Implement email in example program. Replication of log files. Server status.
 //!
@@ -92,17 +97,15 @@
 //!
 //! Work on improving/testing SQL code, browse schema, float I/O. Login.
 //!
-//! If updating several databases atomically, want to be able to share the upd file.
-//! So have mechanism to put updates to several files in one upd file.
 
 pub use crate::{
     atomfile::AtomicFile,
+    builtin::standard_builtins,
     gentrans::{GenTransaction, Part},
     init::INITSQL,
     pstore::{AccessPagedData, SharedPagedData},
     stg::{MemFile, SimpleFileStorage, Storage},
     webtrans::WebTransaction,
-    builtin::standard_builtins,
 };
 
 #[cfg(feature = "builtin")]
@@ -131,7 +134,7 @@ use crate::{
     parse::Parser,
     run::*,
     sortedfile::{Asc, Id, Record, SortedFile},
-    table::{ColInfo, IndexInfo, Row, SaveOp, Table, TablePtr},
+    table::{ColInfo, IndexInfo, Row, SaveOp, Table},
     util::{nd, newmap, SmallSet},
     value::*,
 };
@@ -193,18 +196,6 @@ pub mod builtin;
 #[cfg(not(feature = "max"))]
 mod builtin;
 
-#[cfg(feature = "max")]
-/// Storage of variable length values : [ByteStorage].
-pub mod bytes;
-#[cfg(not(feature = "max"))]
-mod bytes;
-
-#[cfg(feature = "max")]
-/// Structs that implement [CExp] trait.
-pub mod cexp;
-#[cfg(not(feature = "max"))]
-mod cexp;
-
 #[cfg(feature = "max")]
 /// [CompactFile] : storage of logical pages in smaller regions of backing storage.
 pub mod compact;
@@ -271,6 +262,14 @@ pub mod value;
 #[cfg(not(feature = "builtin"))]
 mod value;
 
+// Private modules.
+
+/// Structs that implement [CExp] trait.
+mod cexp;
+
+/// Storage of variable length values : [ByteStorage].
+mod bytes;
+
 // End of modules.
 
 /// ```Arc<Vec<u8>>```
@@ -286,28 +285,42 @@ pub type BuiltinMap = HashMap<String, (DataKind, CompileFunc)>;
 pub struct Database {
     /// Page storage.
     pub file: AccessPagedData,
-    // System tables.
-    pub sys_schema: TablePtr,
-    pub sys_table: TablePtr,
-    pub sys_column: TablePtr,
-    pub sys_index: TablePtr,
-    pub sys_index_col: TablePtr,
-    pub sys_function: TablePtr,
-    /// Storage of variable length data.
-    pub bs: Vec<ByteStorage>,
-    // Various maps for named database objects.
-    pub schemas: RefCell<HashMap<String, i64>>,
-    pub tables: RefCell<HashMap<ObjRef, TablePtr>>,
-    pub functions: RefCell<HashMap<ObjRef, FunctionPtr>>,
+
+    /// Defined builtin functions.
     pub builtins: Arc<BuiltinMap>,
-    /// Flag to reset the functions cache after save.
-    pub function_reset: Cell<bool>,
+
+    // System tables.
+    ///
+    pub sys_schema: Rc<Table>,
+    ///
+    pub sys_table: Rc<Table>,
+    ///
+    pub sys_column: Rc<Table>,
+    ///
+    pub sys_index: Rc<Table>,
+    ///
+    pub sys_index_col: Rc<Table>,
+    ///
+    pub sys_function: Rc<Table>,
+
+    /// Cache of loaded Schemas.
+    pub schemas: RefCell<HashMap<String, i64>>,
+    /// Cache of loaded Tables.
+    pub tables: RefCell<HashMap<ObjRef, Rc<Table>>>,
+    /// Cache of loaded Functions.
+    pub functions: RefCell<HashMap<ObjRef, FunctionPtr>>,
+
     /// Last id generated by INSERT.
     pub lastid: Cell<i64>,
     /// Has there been an error since last save?
     pub err: Cell<bool>,
+
+    /// Storage of variable length data.
+    bs: Vec<ByteStorage>,
+    /// Flag to reset the functions cache after save.
+    function_reset: Cell<bool>,
     /// Maximum size of logical page.
-    pub page_size_max: usize,
+    page_size_max: usize,
 }
 
 const SYS_ROOT_LAST: u64 = 15;
@@ -434,7 +447,7 @@ GO
     }
 
     /// Run a batch of SQL.
-    pub(crate) fn go(self: &DB, source: &str, tr: &mut dyn Transaction) -> Option<SqlError> {
+    fn go(self: &DB, source: &str, tr: &mut dyn Transaction) -> Option<SqlError> {
         let mut p = Parser::new(source, self);
         let result = std::panic::catch_unwind(panic::AssertUnwindSafe(|| {
             p.batch(tr);
@@ -459,28 +472,6 @@ GO
         }
     }
 
-    #[cfg(feature = "pack")]
-    pub(crate) fn repack_file(self: &DB, k: i64, schema: &str, tname: &str) -> i64 {
-        if k >= 0 {
-            let name = ObjRef::new(schema, tname);
-            if let Some(t) = self.get_table(&name) {
-                return t.repack(self, k as usize);
-            }
-        } else {
-            let k = (-k - 1) as usize;
-            if k < 4 {
-                return self.bs[k].repack_file(self);
-            }
-        }
-        -1
-    }
-
-    #[cfg(feature = "pack")]
-    /// Get size of logical page.
-    pub(crate) fn lp_size(&self, pnum: u64) -> u64 {
-        self.file.spd.file.read().unwrap().lp_size(pnum) as u64
-    }
-
     /// Save updated tables to underlying file ( or rollback if there was an error ).
     /// Returns the number of logical pages that were updated.
     pub fn save(self: &DB) -> usize {
@@ -517,6 +508,108 @@ GO
         self.file.save(op)
     }
 
+    #[cfg(not(feature = "max"))]
+    /// Get the named table.
+    fn get_table(self: &DB, name: &ObjRef) -> Option<Rc<Table>> {
+        if let Some(t) = self.tables.borrow().get(name) {
+            return Some(t.clone());
+        }
+        sys::get_table(self, name)
+    }
+
+    #[cfg(feature = "max")]
+    /// Get the named table.
+    pub fn get_table(self: &DB, name: &ObjRef) -> Option<Rc<Table>> {
+        if let Some(t) = self.tables.borrow().get(name) {
+            return Some(t.clone());
+        }
+        sys::get_table(self, name)
+    }
+
+    /// Get the named function.
+    fn get_function(self: &DB, name: &ObjRef) -> Option<FunctionPtr> {
+        if let Some(f) = self.functions.borrow().get(name) {
+            return Some(f.clone());
+        }
+        sys::get_function(self, name)
+    }
+
+    /// Insert the table into the map of tables.
+    fn publish_table(&self, table: Rc<Table>) {
+        let name = table.info.name.clone();
+        self.tables.borrow_mut().insert(name, table);
+    }
+
+    /// Get code for value.
+    fn encode(self: &DB, val: &Value, size: usize) -> Code {
+        let bytes = match val {
+            Value::RcBinary(x) => &**x,
+            Value::ArcBinary(x) => &**x,
+            Value::String(x) => x.as_bytes(),
+            _ => {
+                return Code {
+                    id: u64::MAX,
+                    ft: 0,
+                };
+            }
+        };
+        if bytes.len() < size {
+            return Code {
+                id: u64::MAX,
+                ft: 0,
+            };
+        }
+        let tbe = &bytes[size - 9..];
+        let ft = bytes::fragment_type(tbe.len());
+        let id = self.bs[ft].encode(self, &bytes[size - 9..]);
+        Code { id, ft }
+    }
+
+    /// Decode u64 to bytes.
+    fn decode(self: &DB, code: Code, inline: usize) -> Vec<u8> {
+        self.bs[code.ft].decode(self, code.id, inline)
+    }
+
+    /// Delete encoding.
+    fn delcode(self: &DB, code: Code) {
+        if code.id != u64::MAX {
+            self.bs[code.ft].delcode(self, code.id);
+        }
+    }
+
+    /// Allocate a page of underlying file storage.
+    fn alloc_page(self: &DB) -> u64 {
+        self.file.alloc_page()
+    }
+
+    /// Free a page of underlying file storage.
+    fn free_page(self: &DB, lpnum: u64) {
+        self.file.free_page(lpnum);
+    }
+
+    #[cfg(feature = "pack")]
+    /// Get size of logical page.
+    fn lp_size(&self, pnum: u64) -> u64 {
+        self.file.spd.file.read().unwrap().lp_size(pnum) as u64
+    }
+
+    #[cfg(feature = "pack")]
+    /// Repack the specified sortedfile.
+    fn repack_file(self: &DB, k: i64, schema: &str, tname: &str) -> i64 {
+        if k >= 0 {
+            let name = ObjRef::new(schema, tname);
+            if let Some(t) = self.get_table(&name) {
+                return t.repack(self, k as usize);
+            }
+        } else {
+            let k = (-k - 1) as usize;
+            if k < 4 {
+                return self.bs[k].repack_file(self);
+            }
+        }
+        -1
+    }
+
     #[cfg(feature = "verify")]
     /// Verify the page structure of the database.
     pub fn verify(self: &DB) -> String {
@@ -543,85 +636,6 @@ GO
             total
         )
     }
-
-    #[cfg(not(feature = "max"))]
-    /// Get the named table.
-    pub(crate) fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
-        if let Some(t) = self.tables.borrow().get(name) {
-            return Some(t.clone());
-        }
-        sys::get_table(self, name)
-    }
-
-    #[cfg(feature = "max")]
-    /// Get the named table.
-    pub fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
-        if let Some(t) = self.tables.borrow().get(name) {
-            return Some(t.clone());
-        }
-        sys::get_table(self, name)
-    }
-
-    /// Get the named function.
-    pub(crate) fn get_function(self: &DB, name: &ObjRef) -> Option<FunctionPtr> {
-        if let Some(f) = self.functions.borrow().get(name) {
-            return Some(f.clone());
-        }
-        sys::get_function(self, name)
-    }
-
-    /// Insert the table into the map of tables.
-    pub(crate) fn publish_table(&self, table: TablePtr) {
-        let name = table.info.name.clone();
-        self.tables.borrow_mut().insert(name, table);
-    }
-
-    /// Get code for value.
-    pub(crate) fn encode(self: &DB, val: &Value, size: usize) -> Code {
-        let bytes = match val {
-            Value::RcBinary(x) => &**x,
-            Value::ArcBinary(x) => &**x,
-            Value::String(x) => x.as_bytes(),
-            _ => {
-                return Code {
-                    id: u64::MAX,
-                    ft: 0,
-                };
-            }
-        };
-        if bytes.len() < size {
-            return Code {
-                id: u64::MAX,
-                ft: 0,
-            };
-        }
-        let tbe = &bytes[size - 9..];
-        let ft = bytes::fragment_type(tbe.len());
-        let id = self.bs[ft].encode(self, &bytes[size - 9..]);
-        Code { id, ft }
-    }
-
-    /// Decode u64 to bytes.
-    pub(crate) fn decode(self: &DB, code: Code, inline: usize) -> Vec<u8> {
-        self.bs[code.ft].decode(self, code.id, inline)
-    }
-
-    /// Delete encoding.
-    pub(crate) fn delcode(self: &DB, code: Code) {
-        if code.id != u64::MAX {
-            self.bs[code.ft].delcode(self, code.id);
-        }
-    }
-
-    /// Allocate a page of underlying file storage.
-    pub(crate) fn alloc_page(self: &DB) -> u64 {
-        self.file.alloc_page()
-    }
-
-    /// Free a page of underyling file storage.
-    pub(crate) fn free_page(self: &DB, lpnum: u64) {
-        self.file.free_page(lpnum);
-    }
 } // end impl Database
 
 impl Drop for Database {
@@ -636,7 +650,7 @@ impl Drop for Database {
 /// For creating system tables.
 struct TableBuilder {
     alloc: usize,
-    list: Vec<TablePtr>,
+    list: Vec<Rc<Table>>,
 }
 impl TableBuilder {
     fn new() -> Self {
@@ -646,7 +660,7 @@ impl TableBuilder {
         }
     }
 
-    fn nt(&mut self, name: &str, ct: &[(&str, DataType)]) -> TablePtr {
+    fn nt(&mut self, name: &str, ct: &[(&str, DataType)]) -> Rc<Table> {
         let root = self.rt();
         let id = 1 + (root - bytes::NFT as u64);
         // println!("Table builder name={} id={} root={}", name, id, root);
