@@ -484,7 +484,7 @@ impl<'a> Parser<'a> {
     }
 
     /// Construct SqlError based on current line/column/rname.
-    pub fn make_error(&self, msg: String) -> SqlError {
+    pub(crate) fn make_error(&self, msg: String) -> SqlError {
         SqlError {
             line: self.prev_source_line,
             column: self.prev_source_column,
