@@ -125,12 +125,17 @@ pub fn to_hex(bytes: &[u8]) -> String {
 #[derive(Default)]
 pub struct SmallSet {
     /// Holds elements < 64 as a bitmap.
-    pub bitset: u64,
+    bitset: u64,
     /// Holds elements >= 64.
-    pub overflow: BTreeSet<usize>,
+    overflow: BTreeSet<usize>,
 }
 
 impl SmallSet {
+    /// The set is empty.
+    pub fn is_empty(&self) -> bool {
+        self.bitset == 0 && self.overflow.len() == 0
+    }
+
     /// Insert x into set.
     pub fn insert(&mut self, x: usize) {
         if x < 64 {
